Module orbits

Module orbits 

The orbits module contains the core types and functions for working with orbital element representations and Two-Line Element (TLE) handling.

Re-exports

pub use keplerian::*;
pub use mean_elements::*;
pub use tle::*;
pub use walker::*;

Modules

keplerian
The keplerian module contains types and functions for working with Keplerian orbital elements.
mean_elements
Mean-Osculating Keplerian element conversions using Brouwer-Lyddane theory. Mean-Osculating Keplerian Element Conversions
tle
Two-Line Element (TLE) format parsing and handling.
walker
Walker Delta constellation generator. Walker constellation generator.