AtmosphericModel

Enum AtmosphericModel 

pub enum AtmosphericModel {
    HarrisPriester,
    NRLMSISE00,
    Exponential {
        scale_height: f64,
        rho0: f64,
        h0: f64,
    },
}
Atmospheric density model

Specifies which model to use for computing atmospheric density. Different models trade off accuracy vs computational cost.

Variants



HarrisPriester

Harris-Priester atmospheric model

Modified Harris-Priester model accounting for diurnal density variations. Valid for altitudes 100-1000 km. Fast and reasonably accurate. Does not require space weather data.



NRLMSISE00

NRLMSISE-00 empirical atmospheric model

Naval Research Laboratory Mass Spectrometer and Incoherent Scatter Radar Exosphere model. High-fidelity model requiring space weather data (F10.7, Ap). Valid from ground to thermospheric heights.



Exponential

Simple exponential atmosphere model

Density varies exponentially with altitude: ρ(h) = ρ₀ exp(-h/H) Very fast but inaccurate. Suitable only for rough estimates.

Fields

scale_height: f64

Scale height [m]

rho0: f64

Reference density at reference altitude [kg/m³]

h0: f64

Reference altitude [m]